import os
import argparse
import urllib.error
import urllib.request
import csv
import mimetypes
import time


def download_file(url, dst_path):
    with urllib.request.urlopen(url) as web_file:
        data = web_file.read()
        extension = mimetypes.guess_extension(web_file.headers["Content-Type"])
        with open(f"{dst_path}{extension}", mode="wb") as local_file:
            local_file.write(data)


def main(
    file_path: str,
    out_path: str,
    name_colum: int = 0,
    target_url_colum: int = 1,
    sleep_time: int = 1,
    prefix: str = "",
    header_skip: bool = False,
):
    csv_file = open(file_path, "r", errors="", newline="")
    list = csv.reader(
        csv_file,
        delimiter=",",
        doublequote=True,
        lineterminator="\r\n",
        quotechar='"',
        skipinitialspace=True,
    )
    if header_skip:
        next(list)
    if not os.path.exists(out_path):
        os.makedirs(out_path)

    for row in list:
        try:
            download_file(
                row[target_url_colum], f"{out_path}/{prefix}{row[name_colum]}"
            )
            time.sleep(sleep_time)
        except ValueError:
            print(f"Can not download url:{row[name_colum]} / {row[target_url_colum]}")
        except urllib.error.URLError as e:
            raise Exception(f"Can not download url:{row[target_url_colum]} \n {e}")


def cli():
    parser = argparse.ArgumentParser()

    parser.add_argument("file_path", metavar="file path")
    parser.add_argument("-o", "--out", dest="out_path", default="./images")
    parser.add_argument("-p", "--prefix", dest="prefix", default="")
    parser.add_argument("-t", "--target-url-col", dest="target_url_colum", default=1, type=int)
    parser.add_argument("-n", "--name-col", dest="name_colum", default=0, type=int)
    parser.add_argument("--sleep", dest="sleep", default=1, type=int)
    parser.add_argument(
        "--header-skip", dest="header_skip", action="store_true", default=False
    )

    option = parser.parse_args()

    main(
        file_path=option.file_path,
        out_path=option.out_path,
        name_colum=option.name_colum,
        target_url_colum=option.target_url_colum,
        sleep_time=option.sleep,
        prefix=option.prefix,
        header_skip=option.header_skip,
    )



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['csv_download']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['csv_download = csv_download.main:cli']}

setup_kwargs = {
    'name': 'csv-download',
    'version': '0.1.2',
    'description': 'Script to specify the column with URL in csv and download and save in bulk.',
    'long_description': '# csv_download\nScript to specify the column with URL in csv and download and save in bulk\n\n\n## usage\n\n`csv_download` reads csv and downloads the URLs of the specified columns in sequence.\nYou can see the available options with `-h`\n```shell\n$ csv_download -h\n\nusage: csv_download [-h] [-o OUT_PATH] [-p PREFIX] [-t TARGET_URL_COLUM] [-n NAME_COLUM] [--sleep SLEEP] [--header-skip] file path\n\npositional arguments:\n   file path\n\noptional arguments:\n   -h, --help show this help message and exit\n   -o OUT_PATH, --out OUT_PATH\n   -p PREFIX, --prefix PREFIX\n   -t TARGET_URL_COLUM, --target-url-col TARGET_URL_COLUM\n   -n NAME_COLUM, --name-col NAME_COLUM\n   --sleep SLEEP\n   --header-skip\n```\n\n### example\n```shell\n$ csv_download ./example/example.csv -o ./image -p example --header-skip\n```\n\n## Author\n[Godan] (https://github.com/godan)\n\n\n\nTranslated with Google Translate',
    'author': 'godan',
    'author_email': 'shogo070920@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Godan/csv_download',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
